==========
User Guide
==========

This user guide covers essential features of pointpats, mostly in the form of interactive Jupyter notebooks. Reading this guide, you will learn:

- descriptive statistics for point patterns 
- quadrat analysis of point patterns
- distance-based tests for clustering in point patterns

Notebooks cover just a small selection of functions as an illustration of
principles. For a full overview of pointpats's capabilities, head to the `API <../api.rst>`_.


.. toctree::
   :maxdepth: 1

	      
   centrography
   sd_ellipse
   Quadrat_statistics
   ripley
   random
   marks


